import { DeviceAlarmEvent, ModeEvent, Hub, RfidEvent, DeviceTriggerEvent, DevicePairEvent } from '../generated-src';
import { Authenticator } from './authenticator';
declare type EventListener<T> = (event: T) => void;
declare type LocationEventListener<T> = (event: T, locationId: string) => void;
export declare enum LocationEventType {
    ConnectionState = "connection_state",
    DeviceAlarm = "device_alarm",
    DevicePair = "device_pair",
    DeviceTrigger = "device_trigger",
    Hub = "hub",
    Mode = "mode",
    Rfid = "rfid"
}
export declare enum ConnectionState {
    Connecting = "connecting",
    Connected = "connected",
    Disconnected = "disconnected",
    Failed = "failed",
    Unavailable = "unavailable"
}
export interface ConnectionStateEvent {
    previous: ConnectionState;
    current: ConnectionState;
}
export declare class LocationListener {
    private readonly authenticator;
    private readonly eventEmitter;
    private connectionState;
    private pusher?;
    constructor(authenticator: Authenticator);
    getConnectionState(): ConnectionState;
    connect(): Promise<void>;
    disconnect(): void;
    addLocation(locationId: string): void;
    removeLocation(locationId: string): void;
    on(eventType: LocationEventType.ConnectionState, listener: EventListener<ConnectionStateEvent>): void;
    on(eventType: LocationEventType.DeviceAlarm, listener: LocationEventListener<DeviceAlarmEvent>): void;
    on(eventType: LocationEventType.DevicePair, listener: LocationEventListener<DevicePairEvent>): void;
    on(eventType: LocationEventType.DeviceTrigger, listener: LocationEventListener<DeviceTriggerEvent>): void;
    on(eventType: LocationEventType.Hub, listener: LocationEventListener<Hub>): void;
    on(eventType: LocationEventType.Mode, listener: LocationEventListener<ModeEvent>): void;
    on(eventType: LocationEventType.Rfid, listener: LocationEventListener<RfidEvent>): void;
    off(eventType: LocationEventType.ConnectionState, listener: EventListener<ConnectionStateEvent>): void;
    off(eventType: LocationEventType.DeviceAlarm, listener: LocationEventListener<DeviceAlarmEvent>): void;
    off(eventType: LocationEventType.DevicePair, listener: LocationEventListener<DevicePairEvent>): void;
    off(eventType: LocationEventType.DeviceTrigger, listener: LocationEventListener<DeviceTriggerEvent>): void;
    off(eventType: LocationEventType.Hub, listener: LocationEventListener<Hub>): void;
    off(eventType: LocationEventType.Mode, listener: LocationEventListener<ModeEvent>): void;
    off(eventType: LocationEventType.Rfid, listener: LocationEventListener<RfidEvent>): void;
    private getAuthConfig;
    private emitConnectionStateEvent;
    private emitDeviceEvent;
    private emit;
}
export {};
